//
//  ViewController.m
//  THMapLocationVC
//
//  Created by xujinjie on 2017/8/29.
//  Copyright © 2017年 tele-hot. All rights reserved.
//

#define THScreenW [UIScreen mainScreen].bounds.size.width

#define THScreenH [UIScreen mainScreen].bounds.size.height

#define THWParam [UIScreen mainScreen].bounds.size.width/375.0f

#define THfloat(a) a*THWParam

#define THMargin THfloat(15)


#import "ViewController.h"
#import <CoreLocation/CoreLocation.h>
#import <MapKit/MapKit.h>
#import "THMapLocation.h"

@interface ViewController ()<CLLocationManagerDelegate,MKMapViewDelegate>
/**
 *  地图
 */
@property(strong, nonatomic) MKMapView *mapview;

@property (nonatomic, strong) CLLocationManager *locationManager;

/**
 创建一个地理编码器，来实现编码和反编码
 */
@property (nonatomic, strong) CLGeocoder *geocoder;

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    [self setMapView];
    
    _geocoder=[[CLGeocoder alloc]init];
    
    [self getLocation];
}

/**
 创建ui
 */
- (void)setMapView{
    
    //地图
    MKMapView *mapview =[[MKMapView alloc]initWithFrame:CGRectMake(0, 0, THScreenW, THfloat(475))];
    mapview.mapType = MKMapTypeStandard ;
    mapview.scrollEnabled = YES;
    mapview.delegate = self;
    self.mapview = mapview;
    [self.view addSubview:mapview];
    
    //查看路线
    UIButton *btnFind = [[UIButton alloc]initWithFrame:CGRectMake(THScreenW/2-THfloat(100), CGRectGetMaxY(mapview.frame)+THfloat(27), THfloat(200), THfloat(18))];
    [btnFind setImage:[UIImage imageNamed:@"activity_area"] forState:UIControlStateNormal];
    [btnFind setTitle:@"查看路线及周边" forState:UIControlStateNormal];
    [btnFind setTitleColor:[UIColor lightGrayColor] forState:UIControlStateNormal];
    btnFind.titleLabel.font = [UIFont systemFontOfSize:THfloat(14)];
    [btnFind addTarget:self action:@selector(turnByTurn) forControlEvents:UIControlEventTouchUpInside];
    [btnFind setTitleEdgeInsets:UIEdgeInsetsMake(0,btnFind.imageView.frame.size.height+THfloat(14), 0.0,0.0)];
    [btnFind setImageEdgeInsets:UIEdgeInsetsMake(0,0,0.0,btnFind.titleLabel.frame.size.height)];
    btnFind.contentHorizontalAlignment = UIControlContentHorizontalAlignmentCenter;
    [self.view addSubview:btnFind];

}

/**
 在地图上定位活动地址
 */
- (void)getLocation{
    [_geocoder geocodeAddressString:@"苏州市灵岩山" completionHandler:^(NSArray *placemarks, NSError *error) {
        NSLog(@"查询记录数: %lu",(unsigned long)[placemarks count]);
        
        if ([placemarks count ] > 0) {
            //移除目前地图上得所有标注点
            [self.mapview removeAnnotations:self.mapview.annotations];
            
        }
        
        for (int i = 0; i< [placemarks count]; i++) {
            CLPlacemark * placemark = placemarks[i];
            
            //调整地图位置和缩放比例,第一个参数是目标区域的中心点，第二个参数：目标区域南北的跨度，第三个参数：目标区域的东西跨度，单位都是米
            MKCoordinateRegion viewRegion = MKCoordinateRegionMakeWithDistance(placemark.location.coordinate, 10000, 10000);
            
            //重新设置地图视图的显示区域
            [self.mapview setRegion:viewRegion animated:YES];
            
            // 实例化 MapLocation 对象
            THMapLocation * annotation = [[THMapLocation alloc] init];
            annotation.streetAddress = placemark.thoroughfare ;
            annotation.city = placemark.locality;
            annotation.state = placemark.administrativeArea ;
            annotation.coordinate = placemark.location.coordinate;
            
            //把标注点MapLocation 对象添加到地图视图上，一旦该方法被调用，地图视图委托方法mapView：ViewForAnnotation:就会被回调
            [self.mapview addAnnotation:annotation];
        }
        
        
    }];
}

- (void)mapView:(MKMapView *)mapView didUpdateUserLocation:(MKUserLocation *)userLocation{
    self.mapview.centerCoordinate = userLocation.location.coordinate;
}

- (void)mapViewDidFailLoadingMap:(MKMapView *)theMapView withError:(NSError *)error {
    NSLog(@"error : %@",[error description]);
}

/**
 打开系统地图查看路线
 */
- (void)turnByTurn{
    
    //地理编码
    [_geocoder geocodeAddressString:@"苏州市灵岩山" completionHandler:^(NSArray *placemarks, NSError *error) {
        CLPlacemark *clPlacemark2=[placemarks firstObject];//获取第一个地标
        MKPlacemark *mkPlacemark2=[[MKPlacemark alloc]initWithPlacemark:clPlacemark2];
        NSDictionary *options=@{MKLaunchOptionsMapTypeKey:@(MKMapTypeStandard),MKLaunchOptionsDirectionsModeKey:MKLaunchOptionsDirectionsModeDriving};
        MKMapItem *mapItem1=[MKMapItem mapItemForCurrentLocation];//当前位置
        MKMapItem *mapItem2=[[MKMapItem alloc]initWithPlacemark:mkPlacemark2];
        [MKMapItem openMapsWithItems:@[mapItem1,mapItem2] launchOptions:options];
    }];
}

-(void)mapView:(MKMapView *)mapView regionDidChangeAnimated:(BOOL)animated{
    [self.mapview removeFromSuperview];
    [self.view addSubview:mapView];
    [self applyMapViewMemoryHotFix];
}

- (void)dealloc {
    self.mapview.showsUserLocation = NO;
    self.mapview.userTrackingMode = MKUserTrackingModeNone;
    [self.mapview.layer removeAllAnimations];
    [self.mapview removeAnnotations:self.mapview.annotations];
    [self.mapview removeOverlays:self.mapview.overlays];
    [self.mapview removeFromSuperview];
    self.mapview.delegate = nil;
    self.mapview = nil;
}

- (void)applyMapViewMemoryHotFix{
    switch (self.mapview.mapType){
        case MKMapTypeHybrid:
        {
            self.mapview.mapType = MKMapTypeStandard;
        }
            break;
        case MKMapTypeStandard:
        {
            self.mapview.mapType = MKMapTypeHybrid;
        } break;
        default:
            break;
    }
    self.mapview.mapType = MKMapTypeStandard;
    
}




@end
